/* tsx-pack v0.0.5 */
'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var path = require('path');
var callSite = require('callsite');
var fs = require('fs');
var htmlMinifierTerser = require('html-minifier-terser');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var path__default = /*#__PURE__*/_interopDefaultLegacy(path);
var callSite__default = /*#__PURE__*/_interopDefaultLegacy(callSite);
var fs__default = /*#__PURE__*/_interopDefaultLegacy(fs);

const isProd = process.env.NODE_ENV !== 'development';
let usedCSSFiles = [];
let usedJSFiles = [];
function useCSS(relativePath) {
    const stack = callSite__default["default"]();
    const requester = stack[1].getFileName();
    const calledDirPath = path__default["default"].dirname(requester);
    const cssFilePath = path__default["default"].join(calledDirPath, relativePath);
    if (usedCSSFiles.includes(cssFilePath))
        return;
    usedCSSFiles.push(cssFilePath);
}
function useJS(relativePath) {
    const stack = callSite__default["default"]();
    const requester = stack[1].getFileName();
    const calledDirPath = path__default["default"].dirname(requester);
    const cssFilePath = path__default["default"].join(calledDirPath, relativePath);
    if (usedJSFiles.includes(cssFilePath))
        return;
    usedJSFiles.push(cssFilePath);
}
async function render(el, relativePath) {
    const html = el;
    usedCSSFiles = [];
    const stack = callSite__default["default"]();
    const requester = stack[1].getFileName();
    const calledDirPath = path__default["default"].dirname(requester);
    let content = '';
    if (isProd) {
        content = await htmlMinifierTerser.minify(html, {
            removeAttributeQuotes: true,
            minifyCSS: true,
            minifyJS: true,
            collapseWhitespace: true,
            removeComments: true
        });
    }
    else {
        content = html;
    }
    fs__default["default"].writeFile(path__default["default"].join(calledDirPath, relativePath), content, err => {
        if (err) {
            console.error(err);
        }
        else {
            console.log(`${relativePath} ✅`);
        }
    });
}
function CSS() {
    let css = '';
    usedCSSFiles.forEach(filePath => {
        const cssFile = fs__default["default"].readFileSync(filePath, 'utf8');
        css += cssFile;
    });
    // @ts-ignore
    return `<style>${css}</style>`;
}
function JS() {
    let js = '';
    usedJSFiles.forEach(filePath => {
        const jsFile = fs__default["default"].readFileSync(filePath, 'utf8');
        js += jsFile;
    });
    // @ts-ignore
    return `<script> (() => { ${js} })() </script>`;
}

exports.CSS = CSS;
exports.JS = JS;
exports.render = render;
exports.useCSS = useCSS;
exports.useJS = useJS;
